@@ -1,19 +1,19 @@
 /* Get address information (partial implementation).
-   Copyright (C) 1997, 2001-2002, 2004-2018 Free Software Foundation, Inc.
+   Copyright (C) 1997, 2001-2002, 2004-2025 Free Software Foundation, Inc.
    Contributed by Simon Josefsson <simon@josefsson.org>.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
-   any later version.
+   This file is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation; either version 2.1 of the
+   License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, see <https://www.gnu.org/licenses/>.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Don't use __attribute__ __nonnull__ in this compilation unit.  Otherwise gcc
    optimizes away the sa == NULL test below.  */
@@ -39,11 +39,9 @@
 /* Get snprintf. */
 #include <stdio.h>
 
-#include <stdbool.h>
-
 #include "gettext.h"
-#define _(String) gettext (String)
-#define N_(String) String
+#define _(msgid) dgettext (GNULIB_TEXT_DOMAIN, msgid)
+#define N_(msgid) msgid
 
 /* BeOS has AF_INET, but not PF_INET.  */
 #ifndef PF_INET
@@ -54,14 +52,52 @@
 # define PF_UNSPEC 0
 #endif
 
-#if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
-# define WINDOWS_NATIVE
-#endif
+#if HAVE_GETADDRINFO
+
+/* Override with cdecl calling convention and mingw fix.  */
+
+int
+getaddrinfo (const char *restrict nodename,
+             const char *restrict servname,
+             const struct addrinfo *restrict hints,
+             struct addrinfo **restrict res)
+# undef getaddrinfo
+{
+  if (hints && (hints->ai_flags & AI_NUMERICSERV) != 0
+      && servname && !(*servname >= '0' && *servname <= '9'))
+    return EAI_NONAME;
+
+  return getaddrinfo (nodename, servname, hints, res);
+}
+
+void
+freeaddrinfo (struct addrinfo *ai)
+# undef freeaddrinfo
+{
+  freeaddrinfo (ai);
+}
+
+#else
+
+# if defined _WIN32 && !defined __CYGWIN__
+#  define WINDOWS_NATIVE
+# endif
 
 /* gl_sockets_startup */
-#include "sockets.h"
+# include "sockets.h"
+
+# ifdef WINDOWS_NATIVE
+
+/* Don't assume that UNICODE is not defined.  */
+#  undef GetModuleHandle
+#  define GetModuleHandle GetModuleHandleA
+
+#  if !(_WIN32_WINNT >= _WIN32_WINNT_WINXP)
+
+/* Avoid warnings from gcc -Wcast-function-type.  */
+#   define GetProcAddress \
+     (void *) GetProcAddress
 
-#ifdef WINDOWS_NATIVE
 typedef int (WSAAPI *getaddrinfo_func) (const char*, const char*,
                                         const struct addrinfo*,
                                         struct addrinfo**);
@@ -78,14 +114,13 @@ static int
 use_win32_p (void)
 {
   static int done = 0;
-  HMODULE h;
 
   if (done)
     return getaddrinfo_ptr ? 1 : 0;
 
   done = 1;
 
-  h = GetModuleHandle ("ws2_32.dll");
+  HMODULE h = GetModuleHandle ("ws2_32.dll");
 
   if (h)
     {
@@ -107,23 +142,73 @@ use_win32_p (void)
 
   return 1;
 }
-#endif
+
+#  else
+
+static int
+use_win32_p (void)
+{
+  static int done = 0;
+
+  if (!done)
+    {
+      done = 1;
+
+      gl_sockets_startup (SOCKETS_1_1);
+    }
+
+  return 1;
+}
+
+#   define getaddrinfo_ptr getaddrinfo
+#   define freeaddrinfo_ptr freeaddrinfo
+#   define getnameinfo_ptr getnameinfo
+
+#  endif
+# endif
 
 static bool
 validate_family (int family)
 {
   /* FIXME: Support more families. */
-#if HAVE_IPV4
-     if (family == PF_INET)
-       return true;
-#endif
-#if HAVE_IPV6
-     if (family == PF_INET6)
-       return true;
-#endif
-     if (family == PF_UNSPEC)
-       return true;
-     return false;
+# if HAVE_IPV4
+   if (family == PF_INET)
+     return true;
+# endif
+# if HAVE_IPV6
+   if (family == PF_INET6)
+     return true;
+# endif
+   if (family == PF_UNSPEC)
+     return true;
+   return false;
+}
+
+static bool
+is_numeric_host (const char *host, int family)
+{
+# if HAVE_IPV4
+  if (family == PF_INET || family == PF_UNSPEC)
+    {
+      /* glibc supports IPv4 addresses in numbers-and-dots notation, that is,
+         also hexadecimal and octal number formats and formats that don't
+         require all four bytes to be explicitly written, via inet_aton().
+         But POSIX doesn't require support for these legacy formats.  Therefore
+         we are free to use inet_pton() instead of inet_aton().  */
+      struct in_addr addr;
+      if (inet_pton (AF_INET, host, &addr))
+        return true;
+    }
+# endif
+# if HAVE_IPV6
+  if (family == PF_INET6 || family == PF_UNSPEC)
+    {
+      struct in6_addr addr;
+      if (inet_pton (AF_INET6, host, &addr))
+        return true;
+    }
+# endif
+  return false;
 }
 
 /* Translate name of a service location and/or a service name to set of
@@ -133,31 +218,34 @@ getaddrinfo (const char *restrict nodename,
              const char *restrict servname,
              const struct addrinfo *restrict hints,
              struct addrinfo **restrict res)
+#undef getaddrinfo
 {
-  struct addrinfo *tmp;
-  int port = 0;
-  struct hostent *he;
-  void *storage;
-  size_t size;
-#if HAVE_IPV6
+# if HAVE_IPV6
   struct v6_pair {
     struct addrinfo addrinfo;
     struct sockaddr_in6 sockaddr_in6;
   };
-#endif
-#if HAVE_IPV4
+# endif
+# if HAVE_IPV4
   struct v4_pair {
     struct addrinfo addrinfo;
     struct sockaddr_in sockaddr_in;
   };
-#endif
+# endif
 
-#ifdef WINDOWS_NATIVE
+# ifdef WINDOWS_NATIVE
   if (use_win32_p ())
-    return getaddrinfo_ptr (nodename, servname, hints, res);
-#endif
+    {
+      if (hints && (hints->ai_flags & AI_NUMERICSERV) != 0
+          && servname && !(*servname >= '0' && *servname <= '9'))
+        return EAI_NONAME;
+      return getaddrinfo_ptr (nodename, servname, hints, res);
+    }
+# endif
 
-  if (hints && (hints->ai_flags & ~(AI_CANONNAME|AI_PASSIVE)))
+  if (hints
+      && (hints->ai_flags
+          & ~(AI_CANONNAME | AI_PASSIVE | AI_NUMERICHOST | AI_NUMERICSERV)))
     /* FIXME: Support more flags. */
     return EAI_BADFLAGS;
 
@@ -169,18 +257,25 @@ getaddrinfo (const char *restrict nodename,
     /* FIXME: Support other socktype. */
     return EAI_SOCKTYPE; /* FIXME: Better return code? */
 
-  if (!nodename)
+  if (nodename != NULL)
+    {
+      if (hints && (hints->ai_flags & AI_NUMERICHOST) != 0
+          && !is_numeric_host (nodename, hints->ai_family))
+        return EAI_NONAME;
+    }
+  else
     {
       if (!(hints->ai_flags & AI_PASSIVE))
         return EAI_NONAME;
 
-#ifdef HAVE_IPV6
+# if HAVE_IPV6
       nodename = (hints->ai_family == AF_INET6) ? "::" : "0.0.0.0";
-#else
+# else
       nodename = "0.0.0.0";
-#endif
+# endif
     }
 
+  int port = 0;
   if (servname)
     {
       struct servent *se = NULL;
@@ -206,35 +301,37 @@ getaddrinfo (const char *restrict nodename,
     }
 
   /* FIXME: Use gethostbyname_r if available. */
-  he = gethostbyname (nodename);
+  struct hostent *he = gethostbyname (nodename);
   if (!he || he->h_addr_list[0] == NULL)
     return EAI_NONAME;
 
+  size_t size;
   switch (he->h_addrtype)
     {
-#if HAVE_IPV6
+# if HAVE_IPV6
     case PF_INET6:
       size = sizeof (struct v6_pair);
       break;
-#endif
+# endif
 
-#if HAVE_IPV4
+# if HAVE_IPV4
     case PF_INET:
       size = sizeof (struct v4_pair);
       break;
-#endif
+# endif
 
     default:
       return EAI_NODATA;
     }
 
-  storage = calloc (1, size);
+  void *storage = calloc (1, size);
   if (!storage)
     return EAI_MEMORY;
 
+  struct addrinfo *tmp;
   switch (he->h_addrtype)
     {
-#if HAVE_IPV6
+# if HAVE_IPV6
     case PF_INET6:
       {
         struct v6_pair *p = storage;
@@ -256,9 +353,9 @@ getaddrinfo (const char *restrict nodename,
         tmp->ai_addrlen = sizeof *sinp;
       }
       break;
-#endif
+# endif
 
-#if HAVE_IPV4
+# if HAVE_IPV4
     case PF_INET:
       {
         struct v4_pair *p = storage;
@@ -280,7 +377,7 @@ getaddrinfo (const char *restrict nodename,
         tmp->ai_addrlen = sizeof *sinp;
       }
       break;
-#endif
+# endif
 
     default:
       free (storage);
@@ -308,21 +405,21 @@ getaddrinfo (const char *restrict nodename,
   tmp->ai_addr->sa_family = he->h_addrtype;
   tmp->ai_family = he->h_addrtype;
 
-#ifdef HAVE_STRUCT_SOCKADDR_SA_LEN
+# ifdef HAVE_STRUCT_SOCKADDR_SA_LEN
   switch (he->h_addrtype)
     {
-#if HAVE_IPV4
+#  if HAVE_IPV4
     case AF_INET:
       tmp->ai_addr->sa_len = sizeof (struct sockaddr_in);
       break;
-#endif
-#if HAVE_IPV6
+#  endif
+#  if HAVE_IPV6
     case AF_INET6:
       tmp->ai_addr->sa_len = sizeof (struct sockaddr_in6);
       break;
-#endif
+#  endif
     }
-#endif
+# endif
 
   /* FIXME: If more than one address, create linked list of addrinfo's. */
 
@@ -334,20 +431,19 @@ getaddrinfo (const char *restrict nodename,
 /* Free 'addrinfo' structure AI including associated storage.  */
 void
 freeaddrinfo (struct addrinfo *ai)
+#undef freeaddrinfo
 {
-#ifdef WINDOWS_NATIVE
+# ifdef WINDOWS_NATIVE
   if (use_win32_p ())
     {
       freeaddrinfo_ptr (ai);
       return;
     }
-#endif
+# endif
 
   while (ai)
     {
-      struct addrinfo *cur;
-
-      cur = ai;
+      struct addrinfo *cur = ai;
       ai = ai->ai_next;
 
       free (cur->ai_canonname);
@@ -360,12 +456,13 @@ getnameinfo (const struct sockaddr *restrict sa, socklen_t salen,
              char *restrict node, socklen_t nodelen,
              char *restrict service, socklen_t servicelen,
              int flags)
+#undef getnameinfo
 {
-#ifdef WINDOWS_NATIVE
+# ifdef WINDOWS_NATIVE
   if (use_win32_p ())
     return getnameinfo_ptr (sa, salen, node, nodelen,
                             service, servicelen, flags);
-#endif
+# endif
 
   /* FIXME: Support other flags. */
   if ((node && nodelen > 0 && !(flags & NI_NUMERICHOST)) ||
@@ -378,18 +475,18 @@ getnameinfo (const struct sockaddr *restrict sa, socklen_t salen,
 
   switch (sa->sa_family)
     {
-#if HAVE_IPV4
+# if HAVE_IPV4
     case AF_INET:
       if (salen < sizeof (struct sockaddr_in))
         return EAI_FAMILY;
       break;
-#endif
-#if HAVE_IPV6
+# endif
+# if HAVE_IPV6
     case AF_INET6:
       if (salen < sizeof (struct sockaddr_in6))
         return EAI_FAMILY;
       break;
-#endif
+# endif
     default:
       return EAI_FAMILY;
     }
@@ -398,23 +495,23 @@ getnameinfo (const struct sockaddr *restrict sa, socklen_t salen,
     {
       switch (sa->sa_family)
         {
-#if HAVE_IPV4
+# if HAVE_IPV4
         case AF_INET:
           if (!inet_ntop (AF_INET,
                           &(((const struct sockaddr_in *) sa)->sin_addr),
                           node, nodelen))
             return EAI_SYSTEM;
           break;
-#endif
+# endif
 
-#if HAVE_IPV6
+# if HAVE_IPV6
         case AF_INET6:
           if (!inet_ntop (AF_INET6,
                           &(((const struct sockaddr_in6 *) sa)->sin6_addr),
                           node, nodelen))
             return EAI_SYSTEM;
           break;
-#endif
+# endif
 
         default:
           return EAI_FAMILY;
@@ -424,12 +521,12 @@ getnameinfo (const struct sockaddr *restrict sa, socklen_t salen,
   if (service && servicelen > 0 && flags & NI_NUMERICSERV)
     switch (sa->sa_family)
       {
-#if HAVE_IPV4
+# if HAVE_IPV4
       case AF_INET:
-#endif
-#if HAVE_IPV6
+# endif
+# if HAVE_IPV6
       case AF_INET6:
-#endif
+# endif
         {
           unsigned short int port
             = ntohs (((const struct sockaddr_in *) sa)->sin_port);
@@ -441,3 +538,5 @@ getnameinfo (const struct sockaddr *restrict sa, socklen_t salen,
 
   return 0;
 }
+
+#endif
