@@ -1,5 +1,5 @@
 /* <uchar.h> substitute - 16-bit and 32-bit wide character types.
-   Copyright (C) 2019-2023 Free Software Foundation, Inc.
+   Copyright (C) 2019-2025 Free Software Foundation, Inc.
 
    This file is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
@@ -21,14 +21,14 @@
  */
 
 #ifndef _@GUARD_PREFIX@_UCHAR_H
-#define _@GUARD_PREFIX@_UCHAR_H
 
 #if __GNUC__ >= 3
 @PRAGMA_SYSTEM_HEADER@
 #endif
 @PRAGMA_COLUMNS@
 
-#if @HAVE_UCHAR_H@
+/* The include_next requires a split double-inclusion guard.  */
+#if (defined __cplusplus ? @CXX_HAVE_UCHAR_H@ : @HAVE_UCHAR_H@)
 # if defined __HAIKU__
 /* Work around <https://dev.haiku-os.org/ticket/17040>.  */
 #  include <stdint.h>
@@ -44,6 +44,9 @@
 # @INCLUDE_NEXT@ @NEXT_UCHAR_H@
 #endif
 
+#ifndef _@GUARD_PREFIX@_UCHAR_H
+#define _@GUARD_PREFIX@_UCHAR_H
+
 /* This file uses _GL_INLINE_HEADER_BEGIN, _GL_INLINE, _GL_BEGIN_C_LINKAGE,
    _GL_ATTRIBUTE_PURE, GNULIB_POSIXCHECK, HAVE_RAW_DECL_*.  */
 #if !_GL_CONFIG_H_INCLUDED
@@ -80,7 +83,7 @@
 _GL_INLINE_HEADER_BEGIN
 
 
-#if !(@HAVE_UCHAR_H@ || (defined __cplusplus && @CXX_HAS_CHAR8_TYPE@))
+#if !(defined __cplusplus ? @CXX_HAVE_UCHAR_H@ || @CXX_HAS_CHAR8_TYPE@ : @HAVE_UCHAR_H@)
 
 /* An 8-bit variant of wchar_t.
    Note: This type is only mandated by ISO C 23 or newer, and it does
@@ -94,7 +97,7 @@ typedef unsigned char gl_char8_t;
 
 #endif
 
-#if !(@HAVE_UCHAR_H@ || (defined __cplusplus && @CXX_HAS_UCHAR_TYPES@))
+#if !(defined __cplusplus ? @CXX_HAVE_UCHAR_H@ || @CXX_HAS_UCHAR_TYPES@ : @HAVE_UCHAR_H@)
 
 /* A 16-bit variant of wchar_t.
    Note: This type is only mandated by ISO C 11 or newer.  In ISO C 23
@@ -109,14 +112,14 @@ typedef uint_least16_t gl_char16_t;
 
 #endif
 
-#if !(@HAVE_UCHAR_H@ || (defined __cplusplus && @CXX_HAS_UCHAR_TYPES@))
+#if !(defined __cplusplus ? @CXX_HAVE_UCHAR_H@ || @CXX_HAS_UCHAR_TYPES@ : @HAVE_UCHAR_H@)
 
 /* A 32-bit variant of wchar_t.
    Note: This type is only mandated by ISO C 11 or newer.  In ISO C 23
    and newer, it denotes UTF-32 code points; in older versions of ISO C
    it did so only on platforms on which __STDC_UTF_32__ was defined.
    In gnulib, we guarantee that it denotes UTF-32 code points if and
-   only if the module 'uchar-c23' is in use.  */
+   only if the module 'uchar-h-c23' is in use.  */
 typedef uint_least32_t char32_t;
 
 #elif @GNULIBHEADERS_OVERRIDE_CHAR32_T@
@@ -159,11 +162,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE _GL_ATTRIBUTE_PURE wint_t
 btoc32 (int c)
 {
-  return btowc (c);
+  return
+#  if @GNULIB_BTOWC@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         btowc (c);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (btoc32, wint_t, (int c) _GL_ATTRIBUTE_PURE);
+_GL_FUNCDECL_SYS (btoc32, wint_t, (int c), _GL_ATTRIBUTE_PURE);
 # endif
 _GL_CXXALIAS_SYS (btoc32, wint_t, (int c));
 _GL_CXXALIASWARN (btoc32);
@@ -177,11 +184,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isalnum (wint_t wc)
 {
-  return iswalnum (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswalnum (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isalnum, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isalnum, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isalnum, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isalnum);
@@ -192,11 +203,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isalpha (wint_t wc)
 {
-  return iswalpha (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswalpha (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isalpha, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isalpha, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isalpha, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isalpha);
@@ -207,11 +222,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isblank (wint_t wc)
 {
-  return iswblank (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswblank (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isblank, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isblank, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isblank, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isblank);
@@ -222,11 +241,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32iscntrl (wint_t wc)
 {
-  return iswcntrl (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswcntrl (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32iscntrl, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32iscntrl, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32iscntrl, int, (wint_t wc));
 _GL_CXXALIASWARN (c32iscntrl);
@@ -237,11 +260,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isdigit (wint_t wc)
 {
-  return iswdigit (wc);
+  return
+#  if @GNULIB_ISWDIGIT@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswdigit (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isdigit, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isdigit, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isdigit, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isdigit);
@@ -252,11 +279,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isgraph (wint_t wc)
 {
-  return iswgraph (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswgraph (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isgraph, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isgraph, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isgraph, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isgraph);
@@ -267,11 +298,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32islower (wint_t wc)
 {
-  return iswlower (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswlower (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32islower, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32islower, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32islower, int, (wint_t wc));
 _GL_CXXALIASWARN (c32islower);
@@ -282,11 +317,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isprint (wint_t wc)
 {
-  return iswprint (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswprint (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isprint, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isprint, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isprint, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isprint);
@@ -297,11 +336,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32ispunct (wint_t wc)
 {
-  return iswpunct (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswpunct (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32ispunct, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32ispunct, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32ispunct, int, (wint_t wc));
 _GL_CXXALIASWARN (c32ispunct);
@@ -312,11 +355,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isspace (wint_t wc)
 {
-  return iswspace (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswspace (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isspace, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isspace, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isspace, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isspace);
@@ -327,11 +374,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isupper (wint_t wc)
 {
-  return iswupper (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswupper (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isupper, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isupper, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isupper, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isupper);
@@ -342,11 +393,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32isxdigit (wint_t wc)
 {
-  return iswxdigit (wc);
+  return
+#  if @GNULIB_ISWXDIGIT@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswxdigit (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32isxdigit, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32isxdigit, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32isxdigit, int, (wint_t wc));
 _GL_CXXALIASWARN (c32isxdigit);
@@ -360,11 +415,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE wint_t
 c32tolower (wint_t wc)
 {
-  return towlower (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         towlower (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32tolower, wint_t, (wint_t wc));
+_GL_FUNCDECL_SYS (c32tolower, wint_t, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32tolower, wint_t, (wint_t wc));
 _GL_CXXALIASWARN (c32tolower);
@@ -375,11 +434,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE wint_t
 c32toupper (wint_t wc)
 {
-  return towupper (wc);
+  return
+#  if defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         towupper (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32toupper, wint_t, (wint_t wc));
+_GL_FUNCDECL_SYS (c32toupper, wint_t, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32toupper, wint_t, (wint_t wc));
 _GL_CXXALIASWARN (c32toupper);
@@ -393,11 +456,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32width (char32_t wc)
 {
-  return wcwidth (wc);
+  return
+#  if @GNULIB_WCWIDTH@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         wcwidth (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32width, int, (char32_t wc));
+_GL_FUNCDECL_SYS (c32width, int, (char32_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32width, int, (char32_t wc));
 _GL_CXXALIASWARN (c32width);
@@ -411,11 +478,11 @@ _GL_CXXALIASWARN (c32width);
 #   undef c32rtomb
 #   define c32rtomb rpl_c32rtomb
 #  endif
-_GL_FUNCDECL_RPL (c32rtomb, size_t, (char *s, char32_t wc, mbstate_t *ps));
+_GL_FUNCDECL_RPL (c32rtomb, size_t, (char *s, char32_t wc, mbstate_t *ps), );
 _GL_CXXALIAS_RPL (c32rtomb, size_t, (char *s, char32_t wc, mbstate_t *ps));
 # else
 #  if !@HAVE_C32RTOMB@
-_GL_FUNCDECL_SYS (c32rtomb, size_t, (char *s, char32_t wc, mbstate_t *ps));
+_GL_FUNCDECL_SYS (c32rtomb, size_t, (char *s, char32_t wc, mbstate_t *ps), );
 #  endif
 _GL_CXXALIAS_SYS (c32rtomb, size_t, (char *s, char32_t wc, mbstate_t *ps));
 # endif
@@ -423,7 +490,6 @@ _GL_CXXALIAS_SYS (c32rtomb, size_t, (char *s, char32_t wc, mbstate_t *ps));
 _GL_CXXALIASWARN (c32rtomb);
 # endif
 #elif defined GNULIB_POSIXCHECK
-# undef c32rtomb
 # if HAVE_RAW_DECL_C32RTOMB
 _GL_WARN_ON_USE (c32rtomb, "c32rtomb is not portable - "
                  "use gnulib module c32rtomb for portability");
@@ -439,13 +505,17 @@ _GL_INLINE _GL_ARG_NONNULL ((2)) size_t
 c32snrtombs (char *dest, const char32_t **srcp, size_t srclen, size_t len,
              mbstate_t *ps)
 {
-  return wcsnrtombs (dest, (const wchar_t **) srcp, srclen, len, ps);
+  return
+#  if @GNULIB_WCSNRTOMBS@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         wcsnrtombs (dest, (const wchar_t **) srcp, srclen, len, ps);
 }
 _GL_END_C_LINKAGE
 # else
 _GL_FUNCDECL_SYS (c32snrtombs, size_t,
                   (char *dest, const char32_t **srcp, size_t srclen, size_t len,
-                   mbstate_t *ps)
+                   mbstate_t *ps),
                   _GL_ARG_NONNULL ((2)));
 # endif
 _GL_CXXALIAS_SYS (c32snrtombs, size_t,
@@ -462,12 +532,17 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE _GL_ARG_NONNULL ((2)) size_t
 c32srtombs (char *dest, const char32_t **srcp, size_t len, mbstate_t *ps)
 {
-  return wcsrtombs (dest, (const wchar_t **) srcp, len, ps);
+  return
+#  if @GNULIB_WCSRTOMBS@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         wcsrtombs (dest, (const wchar_t **) srcp, len, ps);
 }
 _GL_END_C_LINKAGE
 # else
 _GL_FUNCDECL_SYS (c32srtombs, size_t,
-                  (char *dest, const char32_t **srcp, size_t len, mbstate_t *ps)
+                  (char *dest, const char32_t **srcp, size_t len,
+                   mbstate_t *ps),
                   _GL_ARG_NONNULL ((2)));
 # endif
 _GL_CXXALIAS_SYS (c32srtombs, size_t,
@@ -492,7 +567,7 @@ c32stombs (char *dest, const char32_t *src, size_t len)
 _GL_END_C_LINKAGE
 # else
 _GL_FUNCDECL_SYS (c32stombs, size_t,
-                  (char *dest, const char32_t *src, size_t len)
+                  (char *dest, const char32_t *src, size_t len),
                   _GL_ARG_NONNULL ((2)));
 # endif
 _GL_CXXALIAS_SYS (c32stombs, size_t,
@@ -508,11 +583,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE _GL_ARG_NONNULL ((1)) int
 c32swidth (const char32_t *s, size_t n)
 {
-  return wcswidth ((const wchar_t *) s, n);
+  return
+#  if @GNULIB_WCSWIDTH@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         wcswidth ((const wchar_t *) s, n);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32swidth, int, (const char32_t *s, size_t n)
+_GL_FUNCDECL_SYS (c32swidth, int, (const char32_t *s, size_t n),
                                   _GL_ARG_NONNULL ((1)));
 # endif
 _GL_CXXALIAS_SYS (c32swidth, int, (const char32_t *s, size_t n));
@@ -529,11 +608,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32tob (wint_t wc)
 {
-  return wctob (wc);
+  return
+#  if @GNULIB_WCTOB@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         wctob (wc);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32tob, int, (wint_t wc));
+_GL_FUNCDECL_SYS (c32tob, int, (wint_t wc), );
 # endif
 _GL_CXXALIAS_SYS (c32tob, int, (wint_t wc));
 _GL_CXXALIASWARN (c32tob);
@@ -548,13 +631,13 @@ _GL_CXXALIASWARN (c32tob);
 #   define mbrtoc32 rpl_mbrtoc32
 #  endif
 _GL_FUNCDECL_RPL (mbrtoc32, size_t,
-                  (char32_t *pc, const char *s, size_t n, mbstate_t *ps));
+                  (char32_t *pc, const char *s, size_t n, mbstate_t *ps), );
 _GL_CXXALIAS_RPL (mbrtoc32, size_t,
                   (char32_t *pc, const char *s, size_t n, mbstate_t *ps));
 # else
 #  if !@HAVE_MBRTOC32@
 _GL_FUNCDECL_SYS (mbrtoc32, size_t,
-                  (char32_t *pc, const char *s, size_t n, mbstate_t *ps));
+                  (char32_t *pc, const char *s, size_t n, mbstate_t *ps), );
 #  endif
 _GL_CXXALIAS_SYS (mbrtoc32, size_t,
                   (char32_t *pc, const char *s, size_t n, mbstate_t *ps));
@@ -563,7 +646,6 @@ _GL_CXXALIAS_SYS (mbrtoc32, size_t,
 _GL_CXXALIASWARN (mbrtoc32);
 # endif
 #elif defined GNULIB_POSIXCHECK
-# undef mbrtoc32
 # if HAVE_RAW_DECL_MBRTOC32
 _GL_WARN_ON_USE (mbrtoc32, "mbrtoc32 is not portable - "
                  "use gnulib module mbrtoc32 for portability");
@@ -580,13 +662,13 @@ _GL_WARN_ON_USE (mbrtoc32, "mbrtoc32 is not portable - "
 #   define mbrtoc16 rpl_mbrtoc16
 #  endif
 _GL_FUNCDECL_RPL (mbrtoc16, size_t,
-                  (char16_t *pc, const char *s, size_t n, mbstate_t *ps));
+                  (char16_t *pc, const char *s, size_t n, mbstate_t *ps), );
 _GL_CXXALIAS_RPL (mbrtoc16, size_t,
                   (char16_t *pc, const char *s, size_t n, mbstate_t *ps));
 # else
-#  if !@HAVE_MBRTOC32@
+#  if !@HAVE_MBRTOC16@
 _GL_FUNCDECL_SYS (mbrtoc16, size_t,
-                  (char16_t *pc, const char *s, size_t n, mbstate_t *ps));
+                  (char16_t *pc, const char *s, size_t n, mbstate_t *ps), );
 #  endif
 _GL_CXXALIAS_SYS (mbrtoc16, size_t,
                   (char16_t *pc, const char *s, size_t n, mbstate_t *ps));
@@ -595,7 +677,6 @@ _GL_CXXALIAS_SYS (mbrtoc16, size_t,
 _GL_CXXALIASWARN (mbrtoc16);
 # endif
 #elif defined GNULIB_POSIXCHECK
-# undef mbrtoc16
 # if HAVE_RAW_DECL_MBRTOC16
 _GL_WARN_ON_USE (mbrtoc16, "mbrtoc16 is not portable - "
                  "use gnulib module mbrtoc16 for portability");
@@ -611,13 +692,17 @@ _GL_INLINE _GL_ARG_NONNULL ((2)) size_t
 mbsnrtoc32s (char32_t *dest, const char **srcp, size_t srclen, size_t len,
              mbstate_t *ps)
 {
-  return mbsnrtowcs ((wchar_t *) dest, srcp, srclen, len, ps);
+  return
+#  if @GNULIB_MBSNRTOWCS@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         mbsnrtowcs ((wchar_t *) dest, srcp, srclen, len, ps);
 }
 _GL_END_C_LINKAGE
 # else
 _GL_FUNCDECL_SYS (mbsnrtoc32s, size_t,
                   (char32_t *dest, const char **srcp, size_t srclen, size_t len,
-                   mbstate_t *ps)
+                   mbstate_t *ps),
                   _GL_ARG_NONNULL ((2)));
 # endif
 _GL_CXXALIAS_SYS (mbsnrtoc32s, size_t,
@@ -634,12 +719,17 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE _GL_ARG_NONNULL ((2)) size_t
 mbsrtoc32s (char32_t *dest, const char **srcp, size_t len, mbstate_t *ps)
 {
-  return mbsrtowcs ((wchar_t *) dest, srcp, len, ps);
+  return
+#  if @GNULIB_MBSRTOWCS@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         mbsrtowcs ((wchar_t *) dest, srcp, len, ps);
 }
 _GL_END_C_LINKAGE
 # else
 _GL_FUNCDECL_SYS (mbsrtoc32s, size_t,
-                  (char32_t *dest, const char **srcp, size_t len, mbstate_t *ps)
+                  (char32_t *dest, const char **srcp, size_t len,
+                   mbstate_t *ps),
                   _GL_ARG_NONNULL ((2)));
 # endif
 _GL_CXXALIAS_SYS (mbsrtoc32s, size_t,
@@ -664,7 +754,7 @@ mbstoc32s (char32_t *dest, const char *src, size_t len)
 _GL_END_C_LINKAGE
 # else
 _GL_FUNCDECL_SYS (mbstoc32s, size_t,
-                  (char32_t *dest, const char *src, size_t len)
+                  (char32_t *dest, const char *src, size_t len),
                   _GL_ARG_NONNULL ((2)));
 # endif
 _GL_CXXALIAS_SYS (mbstoc32s, size_t,
@@ -697,11 +787,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE _GL_ARG_NONNULL ((1)) c32_type_test_t
 c32_get_type_test (const char *name)
 {
-  return wctype (name);
+  return
+#  if @GNULIB_WCTYPE@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         wctype (name);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32_get_type_test, c32_type_test_t, (const char *name)
+_GL_FUNCDECL_SYS (c32_get_type_test, c32_type_test_t, (const char *name),
                                                       _GL_ARG_NONNULL ((1)));
 # endif
 _GL_CXXALIAS_SYS (c32_get_type_test, c32_type_test_t, (const char *name));
@@ -720,16 +814,20 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE int
 c32_apply_type_test (wint_t wc, c32_type_test_t property)
 {
-  return iswctype (wc, property);
+  return
+#  if @GNULIB_ISWCTYPE@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         iswctype (wc, property);
 }
 _GL_END_C_LINKAGE
 #  else
 _GL_FUNCDECL_SYS (c32_apply_type_test, int,
-                  (wint_t wc, c32_type_test_t property));
+                  (wint_t wc, c32_type_test_t property), );
 #  endif
 # else
 _GL_FUNCDECL_SYS (c32_apply_type_test, int,
-                  (wint_t wc, c32_type_test_t property)
+                  (wint_t wc, c32_type_test_t property),
                   _GL_ARG_NONNULL ((2)));
 # endif
 _GL_CXXALIAS_SYS (c32_apply_type_test, int,
@@ -761,11 +859,15 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE _GL_ARG_NONNULL ((1)) c32_mapping_t
 c32_get_mapping (const char *name)
 {
-  return wctrans (name);
+  return
+#  if @GNULIB_WCTRANS@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         wctrans (name);
 }
 _GL_END_C_LINKAGE
 # else
-_GL_FUNCDECL_SYS (c32_get_mapping, c32_mapping_t, (const char *name)
+_GL_FUNCDECL_SYS (c32_get_mapping, c32_mapping_t, (const char *name),
                                                   _GL_ARG_NONNULL ((1)));
 # endif
 _GL_CXXALIAS_SYS (c32_get_mapping, c32_mapping_t, (const char *name));
@@ -783,12 +885,16 @@ _GL_BEGIN_C_LINKAGE
 _GL_INLINE _GL_ARG_NONNULL ((2)) wint_t
 c32_apply_mapping (wint_t wc, c32_mapping_t mapping)
 {
-  return towctrans (wc, mapping);
+  return
+#  if @GNULIB_TOWCTRANS@ && defined __cplusplus && defined GNULIB_NAMESPACE
+         GNULIB_NAMESPACE::
+#  endif
+         towctrans (wc, mapping);
 }
 _GL_END_C_LINKAGE
 # else
 _GL_FUNCDECL_SYS (c32_apply_mapping, wint_t,
-                  (wint_t wc, c32_mapping_t mapping)
+                  (wint_t wc, c32_mapping_t mapping),
                   _GL_ARG_NONNULL ((2)));
 # endif
 _GL_CXXALIAS_SYS (c32_apply_mapping, wint_t,
@@ -800,3 +906,4 @@ _GL_CXXALIASWARN (c32_apply_mapping);
 _GL_INLINE_HEADER_END
 
 #endif /* _@GUARD_PREFIX@_UCHAR_H */
+#endif /* _@GUARD_PREFIX@_UCHAR_H */
