@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2012 Tim Ruehsen
- * Copyright (c) 2015-2023 Free Software Foundation, Inc.
+ * Copyright (c) 2015-2024 Free Software Foundation, Inc.
  *
  * This file is part of libwget.
  *
@@ -153,20 +153,41 @@ static void add_mirror(metalink_context *ctx, const char *value)
 	wget_metalink *metalink = ctx->metalink;
 	wget_metalink_mirror *mirror = wget_calloc(1, sizeof(wget_metalink_mirror));
 
-	wget_strscpy(mirror->location, ctx->location, sizeof(mirror->location));
-	mirror->priority = ctx->priority;
-	mirror->iri = iri;
+	if (mirror) {
+		wget_strscpy(mirror->location, ctx->location, sizeof(mirror->location));
+		mirror->priority = ctx->priority;
+		mirror->iri = iri;
 
-	if (!metalink->mirrors) {
-		metalink->mirrors = wget_vector_create(4, NULL);
-		wget_vector_set_destructor(metalink->mirrors, mirror_free);
+		if (!metalink->mirrors) {
+			metalink->mirrors = wget_vector_create(4, NULL);
+			wget_vector_set_destructor(metalink->mirrors, mirror_free);
+		}
+		wget_vector_add(metalink->mirrors, mirror);
 	}
-	wget_vector_add(metalink->mirrors, mirror);
 
 	*ctx->location = 0;
 	ctx->priority = 999999;
 }
 
+static const char *sanitized_filename(const char *in)
+{
+	// RFC 5854:
+	//   The path MUST NOT contain any directory traversal
+	//   directives or information.  The path MUST be relative.  The path
+	//   MUST NOT begin with a "/", "./", or "../"; contain "/../"; or end
+	//   with "/..".
+	if (*in == '/'
+	    || !strncmp(in, "./", 2)
+	    || !strncmp(in, "../", 3)
+	    || strstr(in, "/../")
+	    || wget_match_tail(in, "/../"))
+	{
+		return NULL;
+	}
+
+	return wget_strdup(in);
+}
+
 static void metalink_parse(void *context, int flags, const char *dir, const char *attr, const char *val, size_t len, size_t pos WGET_GCC_UNUSED)
 {
 	metalink_context *ctx = context;
@@ -192,7 +213,7 @@ static void metalink_parse(void *context, int flags, const char *dir, const char
 		if (attr) {
 			if (*dir == 0) { // /metalink/file
 				if (!ctx->metalink->name && !wget_strcasecmp_ascii(attr, "name")) {
-					ctx->metalink->name = wget_strdup(value);
+					ctx->metalink->name = sanitized_filename(value);
 				}
 			} else if (!wget_strcasecmp_ascii(dir, "/verification/pieces")) {
 				if (!wget_strcasecmp_ascii(attr, "type")) {
@@ -237,7 +258,7 @@ static void metalink_parse(void *context, int flags, const char *dir, const char
 		if (attr) {
 			if (*dir == 0) { // /metalink/file
 				if (!ctx->metalink->name && !wget_strcasecmp_ascii(attr, "name")) {
-					ctx->metalink->name = wget_strdup(value);
+					ctx->metalink->name = sanitized_filename(value);
 				}
 			} else if (!wget_strcasecmp_ascii(dir, "/pieces")) {
 				if (!wget_strcasecmp_ascii(attr, "type")) {
@@ -303,9 +324,9 @@ void wget_metalink_free(wget_metalink **metalink)
 }
 
 WGET_GCC_PURE
-static int compare_mirror(wget_metalink_mirror **m1, wget_metalink_mirror **m2)
+static int compare_mirror(wget_metalink_mirror *m1, wget_metalink_mirror *m2)
 {
-	return (*m1)->priority - (*m2)->priority;
+	return m1->priority - m2->priority;
 }
 
 void wget_metalink_sort_mirrors(wget_metalink *metalink)
