@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2013-2014 Tim Ruehsen
- * Copyright (c) 2015-2022 Free Software Foundation, Inc.
+ * Copyright (c) 2015-2024 Free Software Foundation, Inc.
  *
  * This file is part of libwget.
  *
@@ -33,6 +33,7 @@
 #ifndef TESTS_LIBTEST_H
 #define TESTS_LIBTEST_H
 
+#include <stdbool.h>
 #include <wget.h>
 
 #ifdef	__cplusplus
@@ -49,6 +50,7 @@ extern "C" {
 #define WGET_TEST_HTTPS_REJECT_CONNECTIONS 1006
 #define WGET_TEST_H2_ONLY 1007
 #define WGET_TEST_SKIP_H2 1008
+#define WGET_TEST_H2_MIN_CONCURRENT_STREAMS 1009
 #define WGET_TEST_FEATURE_MHD 1101
 #define WGET_TEST_FEATURE_TLS 1102
 #define WGET_TEST_FEATURE_IDN 1103
@@ -76,7 +78,7 @@ extern "C" {
 #define WGET_TEST_POST_HANDSHAKE_AUTH 3002
 
 // for OCSP testing
-#define WGET_TEST_OCSP_RESP_FILE 3003
+#define WGET_TEST_OCSP_RESP_FILES 3003
 
 typedef enum {
 	INTERRUPT_RESPONSE_DISABLED = 0,
@@ -155,7 +157,8 @@ typedef struct {
 
 	bool
 		https_only : 1,
-		http_only : 1;
+		http_only : 1,
+		h2_delay_response : 1;
 } wget_test_url_t;
 
 WGETAPI void wget_test_stop_server(void);
